---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.


**To Reproduce**
Steps to reproduce the behavior.


**Expected behavior**
A clear and concise description of what you expected to happen.


**Related log**
If your log exceeds 32 lines, please don't paste it here directly and use [Gist](https://gist.github.com) instead.


**Environment (please complete the following information):**
 - OS: [e.g. Ubuntu 18.04]
 - Version [e.g. v0.2.1-2b7c7fe9a414e4faac74451620245ddd3728de5a]


**Additional context**
Add any other context about the problem here.
